@@ -1,5 +1,5 @@
 from .context import Context
-from .sprite import Ball, GameOverText, Paddle, PointCounter
+from .sprite import Ball, OverlayText, Paddle, PointCounter
 
 
 def main() -> None:
@@ -7,7 +7,7 @@ def main() -> None:
     context.register_sprite(Ball(context))
     context.register_sprite(Paddle(context))
     context.register_sprite(PointCounter(context))
-    context.register_sprite(GameOverText(context))
+    context.register_sprite(OverlayText(context))
     try:
         context.mainloop()
     except KeyboardInterrupt:
